%global modname grako
%global modfirst %(c=%{modname}; echo ${c:0:1})

Name:           python-%{modname}
Version:        3.18.0
Release:        3%{?dist}
Summary:        Python grammar compiler, EBNF input, PEG/Packrat parser output

License:        BSD
URL:            https://pypi.python.org/pypi/%{modname}/
Source0:        https://pypi.io/packages/source/%{modfirst}/%{modname}/%{modname}-%{version}.tar.gz

# Fedora-specific patch - test with Python 3, not 2
Patch1:         python-%{modname}-py3.patch

BuildArch:      noarch
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
# needed for tests:
BuildRequires:  python%{python3_pkgversion}-pytest

%description
Grako (for "grammar compiler") takes a grammar in a variation of EBNF
as input, and outputs a memoizing PEG/Packrat parser in Python.

%package -n python%{python3_pkgversion}-%{modname}
Summary:        %{summary}
Requires:       python%{python3_pkgversion}-pygraphviz
%{?python_provide:%python_provide python%{python3_pkgversion}-%{modname}}

%description -n python%{python3_pkgversion}-%{modname}
Grako (for "grammar compiler") takes a grammar in a variation of EBNF
as input, and outputs a memoizing PEG/Packrat parser in Python.

%prep
%setup -q -n %{modname}-%{version}
%patch1 -p1 -b .py3

# Don't package examples/antlr2grako/.ropeproject 
rm -rf examples/antlr2grako/.ropeproject
# examples/*/Makefile patched to use python3, don't need Makefile.py3
rm -f examples/*/Makefile.py3

# In Python shebang lines, remove use of /usr/bin/env,
# without changing timestamps, and set as executable.
# If no shebang, set as non-executable.
for f in `find . -name \*.py`
do
    if head -1 $f | grep --quiet '^#!'
    then
        sed '1 s_^.*$_#!/usr/bin/python3_' $f >$f.new
        touch -r $f $f.new
        mv $f.new $f
        chmod a+x $f
    else
        chmod a-x $f
    fi
done


%build
%py3_build

%check
# make directory needed for bootstrap test
mkdir tmp
# can't just use "make test" because depends on calc example which is missing
make grako_test
make regex_test
make antlr_test

# examples in doc should not be prebuilt, so clean up
cd examples/regex
make clean
rm __pycache__/parser_base.*.pyc
cd ../..

cd examples/antlr2grako
make clean
rm __pycache__/antlr_parser.*.pyc
cd ../..


%install
%py3_install
# install loses the executable permission on bootstrap.py, so fix
chmod a+x %{buildroot}%{python3_sitelib}/%{modname}/bootstrap.py


%files -n python%{python3_pkgversion}-%{modname}
%license LICENSE.txt
%doc DESCRIPTION.rst README.md
%doc examples
%{_bindir}/%{modname}
%{python3_sitelib}/%{modname}
%{python3_sitelib}/%{modname}-%{version}-py?.?.egg-info

%changelog
* Tue Dec 13 2016 Eric Smith <brouhaha@fedoraproject.org> 3.18.0-3
- Fix dependency on python3-pygraphviz, and move into subpackage.
- Fix shebang lines of examples.
- Clean examples after check.

* Mon Dec 12 2016 Eric Smith <brouhaha@fedoraproject.org> 3.18.0-2
- Add dependency on python3-pygraphviz per package review.
- Add a "mkdir tmp" so diagram test passes.
- Added examples directory as doc.

* Sat Dec 10 2016 Eric Smith <brouhaha@fedoraproject.org> 3.18.0-1
- Updated to latest upstream
- Changes per package review (#1401276).

* Sun Dec 04 2016 Eric Smith <brouhaha@fedoraproject.org> 3.17.0-1
- Initial version.
